<template>
    <div>
        <h5 class="q-ma-md">Party</h5>
        <q-form class="column q-pa-md q-gutter-md">
            <q-label>Party Type</q-label>
            <div class="row q-gutter-md">
                <q-radio class="size-2" v-model="party_type" val="patient" label="Patient" />
                <q-radio class="size-2" v-model="party_type" val="doctor" label="Doctor" />
                <q-radio class="size-2" v-model="party_type" val="employee" label="Doctor" />
                <q-radio class="size-2" v-model="party_type" val="tpa_psu" label="TPA/PSU" />
                <q-radio class="size-2" v-model="party_type" val="vendor" label="Vendor" />
                <q-checkbox v-if="party_type === 'vendor'" class="size-2" v-model="formData.is_pharmacy" :true-value="1"
                    :false-value="0" value="1" label="Pharmacy" />
            </div>
            <q-separator />
            <q-label>Basic Details</q-label>
            <div class="row q-gutter-md">
                <q-select :options="['Mr', 'Mrs', 'Master']" class="size-2" dense outlined label="Salutation" />
                <q-input dense outlined class="size-6" label="Party Name" />
                <div class="row size-3">
                <q-input dense outlined v-model="age.years" class="size-1" placeholder="YY" />
                <q-input dense outlined v-model="age.months" class="size-1" placeholder="MM" />
                <q-input dense outlined v-model="age.days" class="size-1" placeholder="DD" />
                </div>
                <q-input dense outlined type="date" v-model="formData.DoB" class="size-3" stack-label label="age" />
                <q-select :options="['Male', 'Female', 'Other']" class="size-2" dense outlined label="Gender" />
                <q-select class="size-3" :options="['Married', 'Unmarried']" dense outlined label="Marital Status" />
            </div>
            <div class="row q-gutter-md" v-if="['patient','doctor','employee'].includes(party_type)">

                <q-input dense outlined class="size-5" label="Father Name" />
                <q-input dense outlined class="size-5" label="Mother Name" />
                <q-input dense outlined class="size-5" label="Spouse Name" />
                <q-input dense outlined class="size-5" label="Occupation Name" />
                <q-input dense outlined class="size-4" label="Religion" />


            </div>
            <q-separator />
            <q-label>Address</q-label>
            <div class="row q-gutter-md">

                <q-input dense outlined class="size-3" label="Pincode" />
                <q-input dense outlined class="size-3" label="Post Office" />
                <q-input dense outlined class="size-3" label="Area/Village" />
                <q-input dense outlined class="size-3" label="Police Station" />
                <q-input dense outlined class="size-3" label="District" />
                <q-input dense outlined class="size-3" label="State" />
                <q-input dense outlined class="size-3" label="Country" />
            </div>
            <div class="row q-gutter-md">
                <q-input dense outlined type="text" class="size-4" label="Extra Detail" />
            </div>
             <q-separator />
             <q-label>Contact Details</q-label>
             <div class="row q-gutter-md">
                <q-input dense outlined type="text" class="size-4" label="Mobile Number" />
                <q-input dense outlined type="text" class="size-4" label="Email" />
            </div>
        </q-form>
    </div>
</template>

<script>
const { date } = Quasar
export default {
    data() {
        return {
            party_type: 'person',
            age: { years: null, months: null, days: null },
            formData: {
                Is_Pharmacy: 0,
                DoB: null
            }
        }
    },
    watch: {
        age: {
            handler(val) {
                console.log('dob', val)
                let current = new Date()
                this.formData.DoB = date.formatDate(date.subtractFromDate(current, val), 'YYYY-MM-DD')
            },
            deep: true
        },
        'formData.DoB': {
            handler(val) {
                console.log('age')
                if (!date.isValid(val)) {
                    this.age = { years: null, months: null, days: null }
                }
                let dob = date.startOfDate(new Date(val), 'days')
                let current = date.startOfDate(new Date(), 'days')

                let years = date.getDateDiff(current, dob, 'years')
                this.age.years = date.getDateDiff(date.subtractFromDate(current, { years }), dob, 'months') < 0 ? years - 1 : years
                current = date.subtractFromDate(current, { years: this.age.years })

                let months = date.getDateDiff(current, dob, 'months')
                this.age.months = date.getDateDiff(date.subtractFromDate(current, { months }), dob, 'days') < 0 ? months - 1 : months
                current = date.subtractFromDate(current, { months: this.age.months })


                let days = date.getDateDiff(current, dob, 'days')
                this.age.days = days < 0 ? 0 : days

            }
        }
    },
    methods: {
        add() {
            console.log(this.formData)
        },
        update() {

        }
    },
    mounted() {
        this.$emit('mounted')
    }
}

</script>